==> libplasma-6.5.5-1.gpkg.tar: image/usr/src/debug/kde-plasma/libplasma-6.5.5/libplasma-6.5.5_build/src/declarativeimports/.qt/rcc/qrc_qmake_org_kde_plasma_components.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0x90,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x1d,0x8,0x35,0x14,0x0,0x56,0x58,0x45,0x1c,0x50,0x55,0x1b,
  0xf,0x52,0x92,0x4c,0x99,0x64,0x12,0x8a,0x1c,0xa5,0xa0,0x8e,0xca,0x86,0x96,0x15,
  0x7b,0x18,0xfd,0x53,0xbb,0x6a,0x70,0x6b,0xd,0x3d,0x0,0x3e,0x0,0x3c,0x0,0x51,
  0xf4,0x97,0x48,0xf0,0x78,0x52,0xd2,0x9b,0xe3,0x96,0x5d,0xa0,0xa6,0xb0,0x66,0xdb,
  0xbc,0xd3,0x90,0x24,0x43,0x76,0x89,0x75,0xbd,0x6d,0xcf,0x22,0xb7,0x7e,0x6b,0x27,
  0x20,0x91,0x7c,0x2e,0xc7,0xb7,0xb0,0xae,0xe3,0x9e,0x93,0xbb,0xb1,0x4e,0x10,0x32,
  0x87,0xdb,0xa0,0x54,0x16,0x68,0x79,0x3f,0xb9,0x4f,0x35,0xb,0xc9,0xc8,0x9,0x2e,
  0x58,0xbe,0xa2,0xbd,0x76,0x44,0x32,0xf4,0x43,0x6,0x7d,0x35,0xaa,0x61,0xdb,0x93,
  0x15,0x9f,0x7b,0xc2,0x3a,0x1f,0x57,0x6e,0x1a,0x34,0x4d,0xb0,0xa4,0xac,0x14,0xbc,
  0x1f,0x93,0x2a,0x56,0x6c,0xdc,0x23,0x38,0xf,0x0,0xa,0x3c,0xdc,0xff,0x8f,0xf0,
  0x9,0xfd,0xdd,0x64,0xe0,0x44,0x51,0x14,0x2d,0xef,0xcf,0x9c,0xbf,0x42,0xae,0x4e,
  0xba,0x29,0x64,0xbb,0xd5,0xa6,0x1e,0x30,0x7d,0xf0,0x9a,0x9c,0x20,0xa4,0x92,0x3e,
  0x9b,0x66,0x2c,0x9,0x5f,0x5b,0x26,0x35,0xb2,0xdb,0x9e,0x1e,0x8a,0x5f,0xa7,0xd2,
  0x7d,0xe4,0xe2,0x56,0x85,0xe,0x24,0x38,0x97,0xbe,0xda,0xdb,0x6b,0xcd,0x9c,0xb,
  0x1b,0x8e,0x2d,0x1f,0x8f,0x3,0x8e,0x4a,0xa7,0xe8,0xe0,0x4e,0x8a,0xc7,0x3d,0xb0,
  0x7c,0xc5,0x3b,0x5d,0xfc,0x3e,0xa4,0xa4,0x21,0xd3,0xa,0x2b,0xf,0x4f,0x4c,0x27,
  0xdc,0x4b,0x7d,0x78,0xee,0x42,0x94,0x8f,0x18,0xf5,0xf6,0x28,0x7e,0xed,0xcb,0x92,
  0xf0,0x59,0x64,0xcf,0x67,0xdd,0xc6,0x14,0x2e,0xe2,0xd6,0x4f,0xb9,0xe9,0x5e,0x93,
  0x1,0x80,0xca,0xa8,0x91,0x96,0x4c,0x91,0x24,0x65,0x24,0x69,0x33,0x30,0x44,0x60,
  0x30,0xe4,0xe6,0x52,0x28,0x48,0x30,0x85,0x92,0x50,0x4b,0x94,0x44,0x12,0x49,0x5,
  0x25,0xca,0xb2,0x77,0xb3,0x4a,0x89,0xc1,0x6e,0xa8,0x2a,0x40,0xd9,0xa9,0x2b,0xd1,
  0x19,0xc9,0xc,0x46,0x2,0xd0,0xb5,0xc5,0x31,0xa8,0xe4,0x7b,0x86,0xa7,0x65,0x12,
  0xce,0x60,0x16,0x4,0x71,0x31,0xc5,0xa2,0xe1,0xb9,0x6f,0x96,0x22,0xe,0x1d,0x21,
  0xb9,0x9f,0xc2,0x32,0x94,0x77,0x40,0x22,0x52,0x3f,0x75,0xf0,0x12,0xc8,0x11,0xd0,
  0x2b,0xa,0xc6,0xf6,0xf7,0x24,0x9b,0xdd,0x78,0x97,0xa0,0x8a,0x96,0x8,0x4d,0x41,
  0x58,0xa0,0x89,0x9,0x4b,0xd1,0xa6,0xcd,0x3e,0x61,0xa8,0x9d,0xe6,0xe6,0x5e,0xcb,
  0x83,0xb2,0x73,0x42,0x45,0xe8,0xc5,0x73,0xd3,0x8a,0xbf,0x33,0xd8,0xf2,0x3c,0x26,
  0xb7,0xac,0x2b,0xd8,0xc3,0xf7,0xcf,0x22,0xb4,0xa3,0x49,0x6a,0xb6,0x41,0x30,0xaf,
  0xfe,0x4d,0x37,0x5a,0xa5,0xde,0x46,0x21,0x3a,0xa9,0xea,0x6b,0x4c,0x39,0x9f,0xf6,
  0xbe,0xf,0xa4,0x38,0x78,0xd3,0x3c,0x4f,0x63,0x8c,0x48,0xa1,0x1b,0x3c,0xc,0x52,
  0x34,0x3,0xe4,0x6d,0xcc,0xcd,0x4b,0xbb,0x2b,0x97,0x68,0xb4,0x91,0x8e,0xce,0x86,
  0x28,0x35,0x66,0x4e,0xd6,0x9d,0x6a,0x59,0x6e,0x42,0xc4,0x1d,0xd7,0xcb,0x8c,0x38,
  0xc4,0x48,0xe0,0xf2,0x6f,0xd1,0xb,0xa3,0x6e,0x67,0x38,0x66,0xd7,0xb9,0xe8,0xa5,
  0xd4,0x64,0x8d,0x43,0x47,0x5b,0xfb,0x80,0x4d,0x6e,0x12,0x40,0x42,0xf8,0xa5,0x6,
  0x20,0x24,0x6b,0xd7,0x28,0x7,0x3a,0xed,0x5b,0xb4,0x61,0x5c,0x68,0xa3,0xe0,0x35,
  0x27,0x3e,0x79,0x7b,0x22,0x98,0x96,0xcb,0x1,0x42,0xb3,0xf2,0xcf,0x0,0xd0,0xe6,
  0x8e,0x33,0xe6,0x5c,0xf,0x29,0x7b,0x8c,0x44,0x64,0x8d,0xf,0xd3,0xcc,0xcb,0x81,
  0x6c,0xbe,0xd1,0x7,0xb4,0x71,0x46,0xc9,0x35,0x6d,0xfe,0x3c,0x55,0xf,0x2b,0xbc,
  0x66,0x90,0xf4,0x5e,0x3a,0xb4,0x40,0x7,0xac,0x64,0x81,0xde,0x65,0xf1,0xd7,0x84,
  0xde,0x3,0x51,0xd9,0xce,0x11,0x22,0x7b,0x9a,0x7c,0x87,0x82,0x73,0x90,0x41,0xd0,
  0xe2,0xc2,0xa8,0xa6,0xe3,0x76,0xd6,0x25,0xe0,0x1d,0xe0,0xc,0x7d,0x4e,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // plasma
  0x0,0x6,
  0x7,0x72,0x8a,0x31,
  0x0,0x70,
  0x0,0x6c,0x0,0x61,0x0,0x73,0x0,0x6d,0x0,0x61,
    // components
  0x0,0xa,
  0x7,0x6a,0x9,0x33,
  0x0,0x63,
  0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,0x6e,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/plasma
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/plasma/components
  0x0,0x0,0x0,0x40,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/plasma/components/qmldir
  0x0,0x0,0x0,0x5a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xc3,0x32,0x8,0x69,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_plasma_components)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_plasma_components)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_plasma_components)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_plasma_components)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_plasma_components)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_plasma_components)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> libplasma-6.5.5-2.gpkg.tar: image/usr/src/debug/kde-plasma/libplasma-6.5.5/libplasma-6.5.5_build/src/declarativeimports/.qt/rcc/qrc_qmake_org_kde_plasma_components.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0x90,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x1d,0x8,0x35,0x14,0x0,0x56,0x58,0x45,0x1c,0x50,0x55,0x1b,
  0xf,0x52,0x92,0x4c,0x99,0x64,0x12,0x8a,0x1c,0xa5,0xa0,0x8e,0xca,0x86,0x96,0x15,
  0x7b,0x18,0xfd,0x53,0xbb,0x6a,0x70,0x6b,0xd,0x3d,0x0,0x3e,0x0,0x3c,0x0,0x51,
  0xf4,0x97,0x48,0xf0,0x78,0x52,0xd2,0x9b,0xe3,0x96,0x5d,0xa0,0xa6,0xb0,0x66,0xdb,
  0xbc,0xd3,0x90,0x24,0x43,0x76,0x89,0x75,0xbd,0x6d,0xcf,0x22,0xb7,0x7e,0x6b,0x27,
  0x20,0x91,0x7c,0x2e,0xc7,0xb7,0xb0,0xae,0xe3,0x9e,0x93,0xbb,0xb1,0x4e,0x10,0x32,
  0x87,0xdb,0xa0,0x54,0x16,0x68,0x79,0x3f,0xb9,0x4f,0x35,0xb,0xc9,0xc8,0x9,0x2e,
  0x58,0xbe,0xa2,0xbd,0x76,0x44,0x32,0xf4,0x43,0x6,0x7d,0x35,0xaa,0x61,0xdb,0x93,
  0x15,0x9f,0x7b,0xc2,0x3a,0x1f,0x57,0x6e,0x1a,0x34,0x4d,0xb0,0xa4,0xac,0x14,0xbc,
  0x1f,0x93,0x2a,0x56,0x6c,0xdc,0x23,0x38,0xf,0x0,0xa,0x3c,0xdc,0xff,0x8f,0xf0,
  0x9,0xfd,0xdd,0x64,0xe0,0x44,0x51,0x14,0x2d,0xef,0xcf,0x9c,0xbf,0x42,0xae,0x4e,
  0xba,0x29,0x64,0xbb,0xd5,0xa6,0x1e,0x30,0x7d,0xf0,0x9a,0x9c,0x20,0xa4,0x92,0x3e,
  0x9b,0x66,0x2c,0x9,0x5f,0x5b,0x26,0x35,0xb2,0xdb,0x9e,0x1e,0x8a,0x5f,0xa7,0xd2,
  0x7d,0xe4,0xe2,0x56,0x85,0xe,0x24,0x38,0x97,0xbe,0xda,0xdb,0x6b,0xcd,0x9c,0xb,
  0x1b,0x8e,0x2d,0x1f,0x8f,0x3,0x8e,0x4a,0xa7,0xe8,0xe0,0x4e,0x8a,0xc7,0x3d,0xb0,
  0x7c,0xc5,0x3b,0x5d,0xfc,0x3e,0xa4,0xa4,0x21,0xd3,0xa,0x2b,0xf,0x4f,0x4c,0x27,
  0xdc,0x4b,0x7d,0x78,0xee,0x42,0x94,0x8f,0x18,0xf5,0xf6,0x28,0x7e,0xed,0xcb,0x92,
  0xf0,0x59,0x64,0xcf,0x67,0xdd,0xc6,0x14,0x2e,0xe2,0xd6,0x4f,0xb9,0xe9,0x5e,0x93,
  0x1,0x80,0xca,0xa8,0x91,0x96,0x4c,0x91,0x24,0x65,0x24,0x69,0x33,0x30,0x44,0x60,
  0x30,0xe4,0xe6,0x52,0x28,0x48,0x30,0x85,0x92,0x50,0x4b,0x94,0x44,0x12,0x49,0x5,
  0x25,0xca,0xb2,0x77,0xb3,0x4a,0x89,0xc1,0x6e,0xa8,0x2a,0x40,0xd9,0xa9,0x2b,0xd1,
  0x19,0xc9,0xc,0x46,0x2,0xd0,0xb5,0xc5,0x31,0xa8,0xe4,0x7b,0x86,0xa7,0x65,0x12,
  0xce,0x60,0x16,0x4,0x71,0x31,0xc5,0xa2,0xe1,0xb9,0x6f,0x96,0x22,0xe,0x1d,0x21,
  0xb9,0x9f,0xc2,0x32,0x94,0x77,0x40,0x22,0x52,0x3f,0x75,0xf0,0x12,0xc8,0x11,0xd0,
  0x2b,0xa,0xc6,0xf6,0xf7,0x24,0x9b,0xdd,0x78,0x97,0xa0,0x8a,0x96,0x8,0x4d,0x41,
  0x58,0xa0,0x89,0x9,0x4b,0xd1,0xa6,0xcd,0x3e,0x61,0xa8,0x9d,0xe6,0xe6,0x5e,0xcb,
  0x83,0xb2,0x73,0x42,0x45,0xe8,0xc5,0x73,0xd3,0x8a,0xbf,0x33,0xd8,0xf2,0x3c,0x26,
  0xb7,0xac,0x2b,0xd8,0xc3,0xf7,0xcf,0x22,0xb4,0xa3,0x49,0x6a,0xb6,0x41,0x30,0xaf,
  0xfe,0x4d,0x37,0x5a,0xa5,0xde,0x46,0x21,0x3a,0xa9,0xea,0x6b,0x4c,0x39,0x9f,0xf6,
  0xbe,0xf,0xa4,0x38,0x78,0xd3,0x3c,0x4f,0x63,0x8c,0x48,0xa1,0x1b,0x3c,0xc,0x52,
  0x34,0x3,0xe4,0x6d,0xcc,0xcd,0x4b,0xbb,0x2b,0x97,0x68,0xb4,0x91,0x8e,0xce,0x86,
  0x28,0x35,0x66,0x4e,0xd6,0x9d,0x6a,0x59,0x6e,0x42,0xc4,0x1d,0xd7,0xcb,0x8c,0x38,
  0xc4,0x48,0xe0,0xf2,0x6f,0xd1,0xb,0xa3,0x6e,0x67,0x38,0x66,0xd7,0xb9,0xe8,0xa5,
  0xd4,0x64,0x8d,0x43,0x47,0x5b,0xfb,0x80,0x4d,0x6e,0x12,0x40,0x42,0xf8,0xa5,0x6,
  0x20,0x24,0x6b,0xd7,0x28,0x7,0x3a,0xed,0x5b,0xb4,0x61,0x5c,0x68,0xa3,0xe0,0x35,
  0x27,0x3e,0x79,0x7b,0x22,0x98,0x96,0xcb,0x1,0x42,0xb3,0xf2,0xcf,0x0,0xd0,0xe6,
  0x8e,0x33,0xe6,0x5c,0xf,0x29,0x7b,0x8c,0x44,0x64,0x8d,0xf,0xd3,0xcc,0xcb,0x81,
  0x6c,0xbe,0xd1,0x7,0xb4,0x71,0x46,0xc9,0x35,0x6d,0xfe,0x3c,0x55,0xf,0x2b,0xbc,
  0x66,0x90,0xf4,0x5e,0x3a,0xb4,0x40,0x7,0xac,0x64,0x81,0xde,0x65,0xf1,0xd7,0x84,
  0xde,0x3,0x51,0xd9,0xce,0x11,0x22,0x7b,0x9a,0x7c,0x87,0x82,0x73,0x90,0x41,0xd0,
  0xe2,0xc2,0xa8,0xa6,0xe3,0x76,0xd6,0x25,0xe0,0x1d,0xe0,0xc,0x7d,0x4e,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // plasma
  0x0,0x6,
  0x7,0x72,0x8a,0x31,
  0x0,0x70,
  0x0,0x6c,0x0,0x61,0x0,0x73,0x0,0x6d,0x0,0x61,
    // components
  0x0,0xa,
  0x7,0x6a,0x9,0x33,
  0x0,0x63,
  0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,0x6e,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/plasma
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/plasma/components
  0x0,0x0,0x0,0x40,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/plasma/components/qmldir
  0x0,0x0,0x0,0x5a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9c,0xa,0xfc,0x11,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_plasma_components)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_plasma_components)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_plasma_components)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_plasma_components)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_plasma_components)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_plasma_components)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
